==> mcp_server_googlesearch-0.1.0-py3-none-any.whl: mcp_server_googlesearch/validation.py <==
"""Input validation utilities for Google Search MCP Server."""

from typing import Dict, Any, Tuple


def validate_google_search_arguments(arguments: Dict[str, Any]) -> Tuple[str, int]:
    """Validate arguments for google_search tool.
    
    Args:
        arguments: Dictionary containing tool arguments
        
    Returns:
        Tuple of (validated_query, validated_num_results)
        
    Raises:
        ValueError: If validation fails with descriptive message
    """
    if not arguments:
        raise ValueError("Missing arguments")
    
    # Validate query parameter
    query = arguments.get("query")
    if query is None:
        raise ValueError("Missing required parameter: query")
    
    if not isinstance(query, str):
        raise ValueError("Query must be a string")
    
    if not query.strip():
        raise ValueError("Query cannot be empty")
    
    # Validate num_results parameter (optional, defaults to 10)
    num_results = arguments.get("num_results", 10)
    
    if not isinstance(num_results, int):
        try:
            num_results = int(num_results)
        except (ValueError, TypeError):
            raise ValueError("num_results must be an integer")
    
    if num_results < 1:
        raise ValueError("num_results must be at least 1")
    
    if num_results > 50:
        raise ValueError("num_results cannot exceed 50")
    
    return query.strip(), num_results


def validate_tool_name(name: str) -> None:
    """Validate that the tool name is supported.
    
    Args:
        name: The tool name to validate
        
    Raises:
        ValueError: If tool name is not supported
    """
    if name != "google_search":
        raise ValueError(f"Unknown tool: {name}")


def create_validation_error_message(field: str, issue: str) -> str:
    """Create a standardized validation error message.
    
    Args:
        field: The field that failed validation
        issue: Description of the validation issue
        
    Returns:
        Formatted validation error message
    """
    return f"Validation Error - {field}: {issue}"

==> mcp_server_googlesearch-0.1.1-py3-none-any.whl: mcp_server_googlesearch/validation.py <==
"""Input validation utilities for Google Search MCP Server."""

from typing import Dict, Any, Tuple


def validate_google_search_arguments(arguments: Dict[str, Any]) -> Tuple[str, int, str, str]:
    """Validate arguments for google_search tool.
    
    Args:
        arguments: Dictionary containing tool arguments
        
    Returns:
        Tuple of (validated_query, validated_num_results, validated_lang, validated_region)
        
    Raises:
        ValueError: If validation fails with descriptive message
    """
    if not arguments:
        raise ValueError("Missing arguments")
    
    # Validate query parameter
    query = arguments.get("query")
    if query is None:
        raise ValueError("Missing required parameter: query")
    
    if not isinstance(query, str):
        raise ValueError("Query must be a string")
    
    if not query.strip():
        raise ValueError("Query cannot be empty")
    
    # Validate num_results parameter (optional, defaults to 10)
    num_results = arguments.get("num_results", 10)
    
    if not isinstance(num_results, int):
        try:
            num_results = int(num_results)
        except (ValueError, TypeError):
            raise ValueError("num_results must be an integer")
    
    if num_results < 1:
        raise ValueError("num_results must be at least 1")
    
    if num_results > 50:
        raise ValueError("num_results cannot exceed 50")
    
    # Validate lang parameter (optional)
    lang = arguments.get("lang")
    if lang is not None:
        if not isinstance(lang, str):
            raise ValueError("lang must be a string")
        if not lang.strip():
            raise ValueError("lang cannot be empty")
        lang = lang.strip()
    
    # Validate region parameter (optional)
    region = arguments.get("region")
    if region is not None:
        if not isinstance(region, str):
            raise ValueError("region must be a string")
        if not region.strip():
            raise ValueError("region cannot be empty")
        region = region.strip()
    
    return query.strip(), num_results, lang, region


def validate_tool_name(name: str) -> None:
    """Validate that the tool name is supported.
    
    Args:
        name: The tool name to validate
        
    Raises:
        ValueError: If tool name is not supported
    """
    if name != "google_search":
        raise ValueError(f"Unknown tool: {name}")


def create_validation_error_message(field: str, issue: str) -> str:
    """Create a standardized validation error message.
    
    Args:
        field: The field that failed validation
        issue: Description of the validation issue
        
    Returns:
        Formatted validation error message
    """
    return f"Validation Error - {field}: {issue}"
